==> firefox-esr_91.12.0esr.orig.tar.xz: firefox-91.12.0/servo/components/style/properties/longhands/inherited_ui.mako.rs <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

<%namespace name="helpers" file="/helpers.mako.rs" />

<% data.new_style_struct("InheritedUI", inherited=True, gecko_name="UI") %>

${helpers.predefined_type(
    "cursor",
    "Cursor",
    "computed::Cursor::auto()",
    engines="gecko servo-2013 servo-2020",
    initial_specified_value="specified::Cursor::auto()",
    animation_value_type="discrete",
    spec="https://drafts.csswg.org/css-ui/#cursor",
)}

// NB: `pointer-events: auto` (and use of `pointer-events` in anything that isn't SVG, in fact)
// is nonstandard, slated for CSS4-UI.
// TODO(pcwalton): SVG-only values.
${helpers.single_keyword(
    "pointer-events",
    "auto none",
    engines="gecko servo-2013 servo-2020",
    animation_value_type="discrete",
    extra_gecko_values="visiblepainted visiblefill visiblestroke visible painted fill stroke all",
    spec="https://www.w3.org/TR/SVG11/interact.html#PointerEventsProperty",
    gecko_enum_prefix="StylePointerEvents",
)}

${helpers.single_keyword(
    "-moz-inert",
    "none inert",
    engines="gecko",
    gecko_ffi_name="mInert",
    gecko_enum_prefix="StyleInert",
    animation_value_type="discrete",
    enabled_in="ua",
    spec="Nonstandard (https://html.spec.whatwg.org/multipage/#inert-subtrees)",
)}

${helpers.single_keyword(
    "-moz-user-input",
    "auto none",
    engines="gecko",
    gecko_ffi_name="mUserInput",
    gecko_enum_prefix="StyleUserInput",
    animation_value_type="discrete",
    spec="Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-input)",
)}

${helpers.single_keyword(
    "-moz-user-modify",
    "read-only read-write write-only",
    engines="gecko",
    gecko_ffi_name="mUserModify",
    gecko_enum_prefix="StyleUserModify",
    needs_conversion=True,
    animation_value_type="discrete",
    spec="Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-modify)",
)}

${helpers.single_keyword(
    "-moz-user-focus",
    "none ignore normal select-after select-before select-menu select-same select-all",
    engines="gecko",
    gecko_ffi_name="mUserFocus",
    gecko_enum_prefix="StyleUserFocus",
    animation_value_type="discrete",
    spec="Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-focus)",
)}

${helpers.predefined_type(
    "caret-color",
    "color::CaretColor",
    "generics::color::CaretColor::auto()",
    engines="gecko",
    spec="https://drafts.csswg.org/css-ui/#caret-color",
    animation_value_type="CaretColor",
    boxed=True,
    ignored_when_colors_disabled=True,
)}

${helpers.predefined_type(
    "accent-color",
    "ColorOrAuto",
    "generics::color::ColorOrAuto::Auto",
    engines="gecko",
    spec="https://drafts.csswg.org/css-ui-4/#widget-accent",
    gecko_pref="layout.css.accent-color.enabled",
    animation_value_type="ColorOrAuto",
    boxed=True,
    ignored_when_colors_disabled=True,
    has_effect_on_gecko_scrollbars=False,
)}

${helpers.predefined_type(
    "scrollbar-color",
    "ui::ScrollbarColor",
    "Default::default()",
    engines="gecko",
    spec="https://drafts.csswg.org/css-scrollbars-1/#scrollbar-color",
    animation_value_type="ScrollbarColor",
    boxed=True,
    ignored_when_colors_disabled=True,
)}

==> firefox-esr_140.4.0esr.orig.tar.xz: firefox-140.4.0/servo/components/style/properties/longhands/inherited_ui.mako.rs <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

<%namespace name="helpers" file="/helpers.mako.rs" />

${helpers.predefined_type(
    "cursor",
    "Cursor",
    "computed::Cursor::auto()",
    engines="gecko servo",
    initial_specified_value="specified::Cursor::auto()",
    animation_type="discrete",
    spec="https://drafts.csswg.org/css-ui/#cursor",
    affects="paint",
)}

${helpers.predefined_type(
    "pointer-events",
    "PointerEvents",
    "specified::PointerEvents::Auto",
    engines="gecko servo",
    animation_type="discrete",
    spec="https://svgwg.org/svg2-draft/interact.html#PointerEventsProperty",
    affects="paint",
)}

${helpers.predefined_type(
    "-moz-inert",
    "Inert",
    "specified::Inert::None",
    engines="gecko",
    gecko_ffi_name="mInert",
    animation_type="discrete",
    enabled_in="ua",
    spec="Nonstandard (https://html.spec.whatwg.org/multipage/#inert-subtrees)",
    affects="paint",
)}

${helpers.predefined_type(
    "-moz-user-input",
    "UserInput",
    "specified::UserInput::Auto",
    engines="gecko",
    gecko_ffi_name="mUserInput",
    animation_type="discrete",
    gecko_pref="layout.css.moz-user-input.enabled",
    has_effect_on_gecko_scrollbars=False,
    spec="Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-input)",
    affects="",
    enabled_in="ua",
)}

${helpers.predefined_type(
    "-moz-user-focus",
    "UserFocus",
    "specified::UserFocus::Normal",
    engines="gecko",
    gecko_ffi_name="mUserFocus",
    animation_type="discrete",
    spec="Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-focus)",
    enabled_in="chrome",
    affects="",
)}

${helpers.predefined_type(
    "caret-color",
    "color::CaretColor",
    "generics::color::CaretColor::auto()",
    engines="gecko",
    spec="https://drafts.csswg.org/css-ui/#caret-color",
    ignored_when_colors_disabled=True,
    affects="paint",
)}

${helpers.predefined_type(
    "accent-color",
    "ColorOrAuto",
    "generics::color::ColorOrAuto::Auto",
    engines="gecko",
    spec="https://drafts.csswg.org/css-ui-4/#widget-accent",
    ignored_when_colors_disabled=True,
    affects="paint",
)}

${helpers.predefined_type(
    "color-scheme",
    "ColorScheme",
    "specified::color::ColorScheme::normal()",
    engines="gecko servo",
    servo_pref="layout.unimplemented",
    spec="https://drafts.csswg.org/css-color-adjust/#color-scheme-prop",
    animation_type="discrete",
    ignored_when_colors_disabled=True,
    affects="paint",
)}

${helpers.predefined_type(
    "scrollbar-color",
    "ScrollbarColor",
    "Default::default()",
    engines="gecko",
    spec="https://drafts.csswg.org/css-scrollbars-1/#scrollbar-color",
    boxed=True,
    ignored_when_colors_disabled=True,
    affects="paint",
)}

${helpers.predefined_type(
    "-moz-theme",
    "MozTheme",
    "specified::MozTheme::Auto",
    engines="gecko",
    enabled_in="chrome",
    animation_type="discrete",
    spec="Internal",
    affects="paint",
)}
